# Plugin do odczytu danych z wykorzystaniem protokolu SNMP
# wersja 3.01
# Jaroslaw Dziub "Jardo" 2012
# Podziekowania dla Ryska za lstat i pomoc w zrozumieniu zasad jego dzialania

package TSNMPTEMPGrapher;

use IPC::Open3;
use vars qw ( @ISA );
use Misc;
use Lstatobj;
use Net::SNMP;

@ISA = qw ( TADVGrapher );

sub new {
 my $proto = shift;
 my $class = ref ($proto) || $proto;
 my $self = $class -> SUPER::new ();
 LoadLangData ('','snmp_temp');
 #setting default values
 $self -> name ( 'snmp_tempXX');
 $self -> {'TITLE_TAG'} = 'TEMPS_DEFTITLE';
 my @IP;
 $self -> {'DESC'}{'ADV'} = [ @IP ]; #reference to statistic info
 $self -> {'DESC'}{'BAR'} = 0;     #0 line or 1 bar
 $self -> {'DESC'}{'IPMT'} = '';
 $self -> {'DESC'}{'COMMUNITY'} = 'public';
 $self -> {'DESC'}{'JEDN'} = 'C';
 $self->AddToRADIOBOX ('BAR'); #for editing as radio box
 $self -> {'HELP_FILE'} = 'temps.html'; #set help file
 $self -> {'MIN_VALUE'} = -25;
 $self -> {'ADV_DESC'} = {name => 'NR', desc => 'SENSOR_NR', size => 25, maxsize => 35};

 bless ($self, $class);
 return $self;
}

sub Create_Object {
 my $self = shift;
 my $rrdstep = shift;
 my $Refsource = shift;

 my $PartRef =  $self -> {'DESC'}{'ADV'}; #reference to array of IPdata

if (@$PartRef) { #has any elements
 my $min_value='0';
  $min_value = $self -> {'MIN_VALUE'} if (exists ($self -> {'MIN_VALUE'}));
  
 for (my $i=0; $i < @$PartRef; $i++) {
   push (@$Refsource,"DS:avg$i:GAUGE:$rrdstep:$min_value:U");
##   push (@$Refsource,"DS:lost$i:ABSOLUTE:$rrdstep:0:U");
#   push (@$Refsource,"DS:lost$i:GAUGE:$rrdstep:0:U");

 }
 return 1;
 } else {return 0}

}

#edit additional primary fields
sub EditObjPrimary {
my $self = shift;
my $RefTags = shift;

#show additional template for this object
Misc::Gen ($RefTags, 'eintpri_snmpTEMP.html',1);
}


#update values in RRD file
sub Update_Object {
 my $self = shift;
 my $data=0;
 my $NRCZ = $self -> {'DESC'}{'ADV'};
my $community = $self->{'DESC'}{'COMMUNITY'};
my $host = $self-> {'DESC'}{'IPMT'} ;



 #store time
 $data=time;
 #find results
 foreach my $row (@$NRCZ) {
  my $nr_c = $$row{'NR'};

		my ($session, $error) = Net::SNMP->session(
		    -hostname => $host,
		    -community => $community,
		);
		if (!defined($session)) {
		printf("ERROR: %s.\n", $error);
		exit 1;
		}		
		my $result = $session->get_request(-varbindlist => [ $nr_c ]);
	#my $wyn_t = $result->{$nr_c};
	#      `echo $wyn_t  >> /root/echoo`;
		$session->close;

  #$data .="\:$wyn_t";
  $data .="\:$result->{$nr_c}";
  }

 #end if
 return ($data);
}


sub Draw_Object {
 my $self = shift;
 my $rrd =shift;
 my $Refsource =shift;

 ResetPalette (); #reset default color palette

 my $RefIP  = $self -> {'DESC'}{'ADV'}; #reference to statistic info
 my $Bar = $self -> {'DESC'}{'BAR'};     #0 line or 1 bar
 my $jed = $self-> {'DESC'}{'JEDN'} ;

 push (@$Refsource,"--vertical-label");
 push (@$Refsource,$dict{TEMP_VLABEL}.$jed);

if (@$RefIP) {
 push (@$Refsource,"COMMENT:$dict{'TEMP_TABLE'}\\n");
 my $spacing;
 my $labelsize=18;
 for (my $i=0; $i < @$RefIP; $i++) {
   my $Row = $$RefIP[$i]; #reference to hash
   my $hide = $Row->{'HIDE'} if (defined ($Row->{'HIDE'}));
   next if ($hide);

  push (@$Refsource,"DEF:avg$i=$rrd:avg$i:AVERAGE");

   my $colour = $Row->{'COLOR'};
   $colour = GetColor () if (! $colour); #automatic
   my $desc = $Row->{'DESC'};
   $desc =$Row->{'NR'} if (! $desc);
  if (!$Bar) {
   #as linie
   $spacing = " " x ($labelsize -length ($desc));
   push (@$Refsource,"LINE1:avg$i\#$colour:$desc");
   push (@$Refsource,"GPRINT:avg$i:AVERAGE:$spacing  %5.2lf $jed ");
   push (@$Refsource,"GPRINT:avg$i:MIN: %5.2lf $jed ");
   push (@$Refsource,"GPRINT:avg$i:MAX: %5.2lf $jed ");
   push (@$Refsource,"GPRINT:avg$i:LAST: %5.2lf $jed\\n");
  }  else {
   if ($i) {
    #not first bar
     push (@$Refsource,"STACK:avg$i\#$colour:$desc");
   } else {
   #first
    push (@$Refsource,"AREA:avg$i\#$colour:$desc");
   }
   }

 } #end for
 } #end if
}

#-------end TEMPGrapher
use Misc;
BEGIN {
RegisterClass ('TSNMPTEMPGrapher', '','snmp_temp','TEMP_DESC',
sub { my $obj; $obj = TSNMPTEMPGrapher -> new (); return ($obj); } );
}

